--------------------------------------------
-- objective map display
--------------------------------------------
-- Background settings
local bg = {
	bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
	edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
	edgeSize = 16,
	insets = {left = 5, right = 5, top = 5, bottom = 5},
	tile = true, tileSize = 16,
}

--------------------------------------------
-- Button frame
--------------------------------------------
local buttonFrame = CreateFrame("Button", nil, UIParent);
TourGuide.statusframe.Map = buttonFrame;

-- Place it the right place
buttonFrame:SetPoint("BOTTOMRIGHT", TourGuide.statusframe, "BOTTOMLEFT", -5);
buttonFrame:SetHeight(24);
buttonFrame:SetWidth(24);
buttonFrame:EnableMouse(true)
buttonFrame:Hide();

buttonFrame.texture = buttonFrame:CreateTexture()
buttonFrame.texture:SetPoint("TOPLEFT", buttonFrame, "TOPLEFT", 2, -2);
buttonFrame.texture:SetPoint("BOTTOMRIGHT", buttonFrame, "BOTTOMRIGHT", -2, 2);
buttonFrame.texture:SetTexture("Interface\\Icons\\Ability_Spy")

--------------------------------------------
-- Map frame
--------------------------------------------
local minW, minH, maxW, maxH = 384, 256, 768, 512
local mapFrame = CreateFrame("Button", nil, UIParent);

-- Place it the right place
mapFrame:SetPoint("TOPRIGHT", TourGuide.statusframe, "BOTTOMRIGHT", -5);
mapFrame:SetWidth(minW + 10);
mapFrame:SetHeight(minH + 10);
mapFrame:SetBackdrop(bg)
mapFrame:SetBackdropColor(0.09, 0.09, 0.19, 0.5)
mapFrame:SetBackdropBorderColor(0.5, 0.5, 0.5, 0.5)
mapFrame:EnableMouse(true)
mapFrame:SetFrameLevel(8)
mapFrame:Hide();

-- Map to be shown
mapFrame.texture = mapFrame:CreateTexture(nil, nil, nil, 1)
mapFrame.texture:SetPoint("TOPLEFT", mapFrame, "TOPLEFT", 5, -5);
mapFrame.texture:SetPoint("BOTTOMRIGHT", mapFrame, "BOTTOMRIGHT", -5, 5);
mapFrame.texture:SetTexCoord(0, 0.75, 0, 1);

-- Map to be shown if failed to load the map
mapFrame.texture2 = mapFrame:CreateTexture()
mapFrame.texture2:SetPoint("TOPLEFT", mapFrame, "TOPLEFT", 5, -5);
mapFrame.texture2:SetPoint("BOTTOMRIGHT", mapFrame, "BOTTOMRIGHT", -5, 5);
mapFrame.texture2:SetTexture("Interface\\AddOns\\TourGuide-Tradeskill\\Maps\\NotFound.tga")
mapFrame.texture2:SetTexCoord(0, 0.75, 0, 1);

-- Map arrow to show where the player are and what heading they are at
mapFrame.arrow = mapFrame:CreateTexture(nil, nil, nil, 2)
mapFrame.arrow:SetPoint("TOPLEFT", 100, -50)
mapFrame.arrow:SetHeight(20)
mapFrame.arrow:SetWidth(20)
mapFrame.arrow:SetTexture("Interface\\AddOns\\TourGuide-Tradeskill\\Maps\\MapArrow.tga")
mapFrame.arrow:Hide()

--------------------------------------------
-- Frame Controll
--------------------------------------------
-- Button script OnClick
buttonFrame:SetScript("OnClick", function(self, button, down)
  if mapFrame:IsShown() then
    mapFrame:Hide()
  else
    mapFrame:Show()
  end
end)

-- Button script OnHide
buttonFrame:SetScript("OnHide", function(self)
  if mapFrame:IsShown() then
    mapFrame:Hide()
  end
end)

-- Map script OnShow
mapFrame:SetScript("OnShow", function(self)
  if TourGuide.tags[TourGuide.current]:match("|MAP|") then
    local info = TourGuide.tags[TourGuide.current]:match("|MAP|([%a%d:%s',_]+)|");
    if info then
      local MapFileName,_,_,_ = strsplit(",", info)
      if MapFileName and strlen(MapFileName) > 0 then
        local changed = self.texture:SetTexture("Interface\\AddOns\\TourGuide-Tradeskill\\Maps\\" .. MapFileName .. ".tga")
      end
    end
  end
end)

-- Map script OnUpdate used to crontroll map arrow
mapFrame:SetScript("OnUpdate", function(self, duration)
  if mapFrame:IsShown() then
    local info = TourGuide.tags[TourGuide.current]:match("|MAP|([%a%d:%s',_]+)|");
    if info then
      local _, MapZone,_,_ = strsplit(",", info)
      if MapZone and strtrim(MapZone) == GetRealZoneText() then
        if (not mapFrame.arrow:IsShown()) then
          self.arrow:Show()
        end
        local x, y = GetPlayerMapPosition("Player");
        local mapW, mapH = (mapFrame:GetWidth() - 10), (mapFrame:GetHeight() - 10)

        self.arrow:SetRotation(GetPlayerFacing())
        self.arrow:SetPoint("TOPLEFT", (mapW * x) + 5 - (self.arrow:GetWidth()/2), -((mapH * y) + 5 - (self.arrow:GetHeight()/2)))
      else
        if mapFrame.arrow:IsShown() then
          self.arrow:Hide()
        end
      end
    end
  end
end)

-- Map script OnHide
mapFrame:SetScript("OnHide", function(self)
  self:SetSize((minW + 10), (minH + 10))
  self.arrow:SetHeight(20)
  self.arrow:SetWidth(20)
end)

-- Map script OnClick
mapFrame:SetScript("OnClick", function(self, button, down)
  local width = mapFrame:GetWidth()
  if ceil(width) == (minW + 10) then
    self:SetWidth(maxW + 10)
    self:SetHeight(maxH + 10)
    self.arrow:SetHeight(40)
    self.arrow:SetWidth(40)
  else
    self:SetWidth(minW + 10)
    self:SetHeight(minH + 10)
    self.arrow:SetHeight(20)
    self.arrow:SetWidth(20)
  end
end)